; LoadBlockToVRAM -- Macro that simplifies calling LoadVRAM to copy data to VRAM
;----------------------------------------------------------------------------
; In: SRCBANK -- bank of source data (00-FF)
;     SRCOFFSET -- offset into SRCBANK of source data
;     DEST -- VRAM address to write to (WORD address!!)
;     SIZE -- number of BYTEs to copy
;----------------------------------------------------------------------------
; Out: None
;----------------------------------------------------------------------------
; Modifies: X, Y
;----------------------------------------------------------------------------
LoadBlockToVRAM .macro (SRCBANK,SRCOFFSET,DEST,SIZE)
                PHB
		PHA
		PHP
		REP #$10
		SEP #$20
		.mem 8
		.index 16
                ldx #DEST
		stx $2116
		LDA #SRCBANK
                PHA
                PLB
                LDX #SRCOFFSET AND $FFFF
		LDY #SIZE
		JSR LoadVRAM
		PLP
		PLA
                PLB
		.endm

;============================================================================
; LoadVRAM -- Load data into VRAM
;----------------------------------------------------------------------------
; In: DS:X  -- points to the data
;     Y     -- Number of bytes to copy (0 to 65535)  (assumes 16-bit index)
;----------------------------------------------------------------------------
; Out: None
;----------------------------------------------------------------------------
; Modifies: none
;----------------------------------------------------------------------------
; Notes:  Assumes VRAM address has been previously set!!
;----------------------------------------------------------------------------
LoadVRAM:
		pha
		phx
		phy			
		php		;Preserve registers
		
		sep #$20	;Careful not to SEP $10, or it will erase upper half of Y!
		.mem 8
		.index 16
		
                stz $420B	;Clear the DMA control register
                stx $4302	;Store the data offset into DMA source offset
                sty $4305       ;Store the size of the data block
                phb
		pla
                sta $4304	;Store the data bank holding the tile data

                lda #$01        ;Set the DMA mode (word, normal increment)
                sta $4300       
                lda #$18        ;Set the destination PPU reg (VRAM gate)
                sta $4301      
                lda #$01        ;Initiate the DMA transfer
                sta $420B

		plp		;Restore registers
		ply
		plx
		pla
		rts		;Return to caller
;============================================================================

;============================================================================
; SetVRAMPointer -- Macro that sets the VRAM pointer register
;----------------------------------------------------------------------------
; In: VIDPTR  -- points to the target address (WORD address!!)
;----------------------------------------------------------------------------
; Out: None
;----------------------------------------------------------------------------
; Modifies: none
;----------------------------------------------------------------------------
SetVRAMPointer	.macro (VIDPTR)
		phx
		ldx #VIDPTR
		stx $2116
		plx
		.endm
;============================================================================
